@@ -17,7 +17,7 @@ def flatten_event(event, flatten_attrs):
     for k, v in event.copy().items():
         if isinstance(v, dict) and "name" in v:
             event[k] = v["name"]
-            if k in ["possession_team", "player"]:
+            if k in ["possession_team", "player", "team"]:
                 event[f"{k}_id"] = v["id"]
     return event
 
@@ -55,7 +55,6 @@ def merge_events_and_frames(
     drop_keys=[
         "event_uuid",
         "visible_area",
-        "match_id",
         "freeze_frame",
         "visible_player_counts",
         "distances_from_edge_of_visible_area",
